#!/usr/bin/python
# -*- coding: utf-8 -*-

# Libervia: a Salut à Toi frontend
# Copyright (C) 2011, 2012, 2013, 2014 Jérôme Poisson <goffi@goffi.org>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from pyjamas.ui.FileUpload import FileUpload
from pyjamas import Window
from pyjamas import DOM


class FilterFileUpload(FileUpload):

    def __init__(self, name, max_size, types=None):
        """
        @param name: the input element name
        @param max_size: maximum file size in MB
        @param types: allowed types as a list of couples (x, y, z):
        - x: MIME content type e.g. "audio/ogg"
        - y: file extension e.g. "*.ogg"
        - z: description for the user e.g. "Ogg Vorbis Audio"
        If types is None, all file format are accepted
        """
        FileUpload.__init__(self)
        self.setName(name)
        while DOM.getElementById(name):
            name = "%s_" % name
        self.setID(name)
        self._id = name
        self.max_size = max_size
        self.types = types

    def getFileInfo(self):
        from __pyjamas__ import JS
        JS("var file = top.document.getElementById(this._id).files[0]; return [file.size, file.type]")

    def check(self):
        if self.getFilename() == "":
            return False
        (size, filetype) = self.getFileInfo()
        if self.types and filetype not in [x for (x, y, z) in self.types]:
            types = ["- %s (%s)" % (z, y) for (x, y, z) in self.types]
            Window.alert('This file type is not accepted.\nAccepted file types are:\n\n%s' % "\n".join(types))
            return False
        if size > self.max_size * pow(2, 20):
            Window.alert('This file is too big!\nMaximum file size: %d MB.' % self.max_size)
            return False
        return True
